@@ -16,7 +16,6 @@ use lspower::jsonrpc::Error as LspError;
 use lspower::jsonrpc::Result as LspResult;
 use lspower::lsp::request::*;
 use lspower::lsp::*;
-use lspower::Client;
 use serde_json::from_value;
 use std::env;
 use std::path::PathBuf;
@@ -30,6 +29,7 @@ use super::analysis::CodeActionCollection;
 use super::analysis::CodeActionData;
 use super::cache::CacheServer;
 use super::capabilities;
+use super::client::Client;
 use super::code_lens;
 use super::completions;
 use super::config::Config;
@@ -61,6 +61,7 @@ use crate::deno_dir;
 use crate::file_fetcher::get_source_from_data_url;
 use crate::fs_util;
 use crate::logger;
+use crate::lsp::logging::lsp_log;
 use crate::tools::fmt::format_file;
 use crate::tools::fmt::format_parsed_source;
 
@@ -299,7 +300,7 @@ impl Inner {
     let maybe_config = workspace_settings.config;
     if let Some(config_str) = &maybe_config {
       if !config_str.is_empty() {
-        info!("Setting TypeScript configuration from: \"{}\"", config_str);
+        lsp_log!("Setting TypeScript configuration from: \"{}\"", config_str);
         let config_url = if let Ok(url) = Url::from_file_path(config_str) {
           Ok(url)
         } else if let Some(root_uri) = maybe_root_uri {
@@ -312,7 +313,7 @@ impl Inner {
             config_str
           ))
         }?;
-        info!("  Resolved configuration file: \"{}\"", config_url);
+        lsp_log!("  Resolved configuration file: \"{}\"", config_url);
 
         let config_file = ConfigFile::from_specifier(&config_url)?;
         return Ok(Some((config_file, config_url)));
@@ -326,12 +327,17 @@ impl Inner {
     if specifier.scheme() == "asset" {
       matches!(
         MediaType::from(specifier),
-        // todo(#12410): Update with new media types for TS 4.5
         MediaType::JavaScript
           | MediaType::Jsx
+          | MediaType::Mjs
+          | MediaType::Cjs
           | MediaType::TypeScript
           | MediaType::Tsx
+          | MediaType::Mts
+          | MediaType::Cts
           | MediaType::Dts
+          | MediaType::Dmts
+          | MediaType::Dcts
       )
     } else {
       self
@@ -388,7 +394,7 @@ impl Inner {
       )
     };
     let maybe_cache_path = if let Some(cache_str) = &maybe_cache {
-      info!("Setting cache path from: \"{}\"", cache_str);
+      lsp_log!("Setting cache path from: \"{}\"", cache_str);
       let cache_url = if let Ok(url) = Url::from_file_path(cache_str) {
         Ok(url)
       } else if let Some(root_uri) = &maybe_root_uri {
@@ -404,7 +410,7 @@ impl Inner {
         ))
       }?;
       let cache_path = fs_util::specifier_to_file_path(&cache_url)?;
-      info!(
+      lsp_log!(
         "  Resolved cache path: \"{}\"",
         cache_path.to_string_lossy()
       );
@@ -439,7 +445,7 @@ impl Inner {
       )
     };
     if let Some(import_map_str) = &maybe_import_map {
-      info!("Setting import map from: \"{}\"", import_map_str);
+      lsp_log!("Setting import map from: \"{}\"", import_map_str);
       let import_map_url = if let Ok(url) = Url::from_file_path(import_map_str)
       {
         Ok(url)
@@ -464,7 +470,7 @@ impl Inner {
         get_source_from_data_url(&import_map_url)?.0
       } else {
         let import_map_path = fs_util::specifier_to_file_path(&import_map_url)?;
-        info!(
+        lsp_log!(
           "  Resolved import map: \"{}\"",
           import_map_path.to_string_lossy()
         );
@@ -489,16 +495,9 @@ impl Inner {
     Ok(())
   }
 
-  pub fn update_debug_flag(&self) -> bool {
+  pub fn update_debug_flag(&self) {
     let internal_debug = self.config.get_workspace_settings().internal_debug;
-    logger::LSP_DEBUG_FLAG
-      .compare_exchange(
-        !internal_debug,
-        internal_debug,
-        Ordering::Acquire,
-        Ordering::Relaxed,
-      )
-      .is_ok()
+    super::logging::set_lsp_debug_flag(internal_debug)
   }
 
   async fn update_registries(&mut self) -> Result<(), AnyError> {
@@ -512,7 +511,7 @@ impl Inner {
       .iter()
     {
       if *enabled {
-        info!("Enabling import suggestions for: {}", registry);
+        lsp_log!("Enabling import suggestions for: {}", registry);
         self.module_registries.enable(registry).await?;
       } else {
         self.module_registries.disable(registry).await?;
@@ -564,6 +563,7 @@ impl Inner {
       "lib": ["deno.ns", "deno.window"],
       "module": "esnext",
       "noEmit": true,
+      "resolveJsonModule": true,
       "strict": true,
       "target": "esnext",
       "useDefineForClassFields": true,
@@ -579,7 +579,7 @@ impl Inner {
       tsconfig.merge(&unstable_libs);
     }
     if let Err(err) = self.merge_user_tsconfig(&mut tsconfig) {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     let _ok: bool = self
       .ts_server
@@ -615,7 +615,7 @@ impl Inner {
     &mut self,
     params: InitializeParams,
   ) -> LspResult<InitializeResult> {
-    info!("Starting Deno language server...");
+    lsp_log!("Starting Deno language server...");
     let mark = self.performance.mark("initialize", Some(&params));
 
     // exit this process when the parent is lost
@@ -631,9 +631,9 @@ impl Inner {
       env!("PROFILE"),
       env!("TARGET")
     );
-    info!("  version: {}", version);
+    lsp_log!("  version: {}", version);
     if let Ok(path) = std::env::current_exe() {
-      info!("  executable: {}", path.to_string_lossy());
+      lsp_log!("  executable: {}", path.to_string_lossy());
     }
 
     let server_info = ServerInfo {
@@ -642,7 +642,7 @@ impl Inner {
     };
 
     if let Some(client_info) = params.client_info {
-      info!(
+      lsp_log!(
         "Connected to \"{}\" {}",
         client_info.name,
         client_info.version.unwrap_or_default(),
@@ -669,13 +669,13 @@ impl Inner {
     self.update_debug_flag();
     // Check to see if we need to change the cache path
     if let Err(err) = self.update_cache() {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_config_file() {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_tsconfig().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
 
     if capabilities.code_action_provider.is_some() {
@@ -692,11 +692,11 @@ impl Inner {
 
     // Check to see if we need to setup the import map
     if let Err(err) = self.update_import_map().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     // Check to see if we need to setup any module registries
     if let Err(err) = self.update_registries().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     self.documents.update_config(
       self.maybe_import_map.clone(),
@@ -740,7 +740,7 @@ impl Inner {
       }
     }
 
-    info!("Server ready.");
+    lsp_log!("Server ready.");
   }
 
   async fn shutdown(&self) -> LspResult<()> {
@@ -893,19 +893,19 @@ impl Inner {
 
     self.update_debug_flag();
     if let Err(err) = self.update_cache() {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_import_map().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_registries().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_config_file() {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.update_tsconfig().await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
     if let Err(err) = self.diagnostics_server.update() {
       error!("{}", err);
@@ -936,7 +936,7 @@ impl Inner {
     if let Some(import_map_uri) = &self.maybe_import_map_uri {
       if changes.iter().any(|uri| import_map_uri == uri) {
         if let Err(err) = self.update_import_map().await {
-          self.client.show_message(MessageType::Warning, err).await;
+          self.client.show_message(MessageType::WARNING, err).await;
         }
         touched = true;
       }
@@ -945,10 +945,10 @@ impl Inner {
     if let Some(config_uri) = &self.maybe_config_uri {
       if changes.iter().any(|uri| config_uri == uri) {
         if let Err(err) = self.update_config_file() {
-          self.client.show_message(MessageType::Warning, err).await;
+          self.client.show_message(MessageType::WARNING, err).await;
         }
         if let Err(err) = self.update_tsconfig().await {
-          self.client.show_message(MessageType::Warning, err).await;
+          self.client.show_message(MessageType::WARNING, err).await;
         }
         touched = true;
       }
@@ -1066,7 +1066,7 @@ impl Inner {
         Ok(Some(text_edits))
       }
     } else {
-      self.client.show_message(MessageType::Warning, format!("Unable to format \"{}\". Likely due to unrecoverable syntax errors in the file.", specifier)).await;
+      self.client.show_message(MessageType::WARNING, format!("Unable to format \"{}\". Likely due to unrecoverable syntax errors in the file.", specifier)).await;
       Ok(None)
     }
   }
@@ -1181,7 +1181,10 @@ impl Inner {
           "deno-lint" => matches!(&d.code, Some(_)),
           "deno" => match &d.code {
             Some(NumberOrString::String(code)) => {
-              code == "no-cache" || code == "no-cache-data"
+              matches!(
+                code.as_str(),
+                "no-cache" | "no-cache-data" | "no-assert-type"
+              )
             }
             _ => false,
           },
@@ -1241,7 +1244,7 @@ impl Inner {
             }
           }
           Some("deno") => code_actions
-            .add_deno_fix_action(diagnostic)
+            .add_deno_fix_action(&specifier, diagnostic)
             .map_err(|err| {
               error!("{}", err);
               LspError::internal_error()
@@ -1616,6 +1619,54 @@ impl Inner {
     }
   }
 
+  async fn goto_type_definition(
+    &mut self,
+    params: GotoTypeDefinitionParams,
+  ) -> LspResult<Option<GotoTypeDefinitionResponse>> {
+    let specifier = self
+      .url_map
+      .normalize_url(&params.text_document_position_params.text_document.uri);
+    if !self.is_diagnosable(&specifier)
+      || !self.config.specifier_enabled(&specifier)
+    {
+      return Ok(None);
+    }
+
+    let mark = self.performance.mark("goto_definition", Some(&params));
+    let asset_or_doc = self.get_cached_asset_or_document(&specifier)?;
+    let line_index = asset_or_doc.line_index();
+    let req = tsc::RequestMethod::GetTypeDefinition {
+      specifier,
+      position: line_index
+        .offset_tsc(params.text_document_position_params.position)?,
+    };
+    let maybe_definition_info: Option<Vec<tsc::DefinitionInfo>> = self
+      .ts_server
+      .request(self.snapshot()?, req)
+      .await
+      .map_err(|err| {
+        error!("Unable to get type definition from TypeScript: {}", err);
+        LspError::internal_error()
+      })?;
+
+    let response = if let Some(definition_info) = maybe_definition_info {
+      let mut location_links = Vec::new();
+      for info in definition_info {
+        if let Some(link) =
+          info.document_span.to_link(line_index.clone(), self).await
+        {
+          location_links.push(link);
+        }
+      }
+      Some(GotoTypeDefinitionResponse::Link(location_links))
+    } else {
+      None
+    };
+
+    self.performance.measure(mark);
+    Ok(response)
+  }
+
   async fn completion(
     &mut self,
     params: CompletionParams,
@@ -1725,6 +1776,12 @@ impl Inner {
           );
           params
         }
+      } else if let Some(url) = data.documentation {
+        CompletionItem {
+          documentation: self.module_registries.get_documentation(&url).await,
+          data: None,
+          ..params
+        }
       } else {
         params
       }
@@ -2264,6 +2321,44 @@ impl Inner {
       Ok(None)
     }
   }
+
+  async fn symbol(
+    &mut self,
+    params: WorkspaceSymbolParams,
+  ) -> LspResult<Option<Vec<SymbolInformation>>> {
+    let mark = self.performance.mark("symbol", Some(&params));
+
+    let req = tsc::RequestMethod::GetNavigateToItems {
+      search: params.query,
+      // this matches vscode's hard coded result count
+      max_result_count: Some(256),
+      file: None,
+    };
+
+    let navigate_to_items: Vec<tsc::NavigateToItem> = self
+      .ts_server
+      .request(self.snapshot()?, req)
+      .await
+      .map_err(|err| {
+        error!("Failed request to tsserver: {}", err);
+        LspError::invalid_request()
+      })?;
+
+    let maybe_symbol_information = if navigate_to_items.is_empty() {
+      None
+    } else {
+      let mut symbol_information = Vec::new();
+      for item in navigate_to_items {
+        if let Some(info) = item.to_symbol_information(self).await {
+          symbol_information.push(info);
+        }
+      }
+      Some(symbol_information)
+    };
+
+    self.performance.measure(mark);
+    Ok(maybe_symbol_information)
+  }
 }
 
 #[lspower::async_trait]
@@ -2384,6 +2479,13 @@ impl lspower::LanguageServer for LanguageServer {
     self.0.lock().await.goto_definition(params).await
   }
 
+  async fn goto_type_definition(
+    &self,
+    params: GotoTypeDefinitionParams,
+  ) -> LspResult<Option<GotoTypeDefinitionResponse>> {
+    self.0.lock().await.goto_type_definition(params).await
+  }
+
   async fn completion(
     &self,
     params: CompletionParams,
@@ -2475,6 +2577,13 @@ impl lspower::LanguageServer for LanguageServer {
   ) -> LspResult<Option<SignatureHelp>> {
     self.0.lock().await.signature_help(params).await
   }
+
+  async fn symbol(
+    &self,
+    params: WorkspaceSymbolParams,
+  ) -> LspResult<Option<Vec<SymbolInformation>>> {
+    self.0.lock().await.symbol(params).await
+  }
 }
 
 // These are implementations of custom commands supported by the LSP
@@ -2513,7 +2622,7 @@ impl Inner {
     }
     let cache_server = self.maybe_cache_server.as_ref().unwrap();
     if let Err(err) = cache_server.cache(roots).await {
-      self.client.show_message(MessageType::Warning, err).await;
+      self.client.show_message(MessageType::WARNING, err).await;
     }
 
     // now that we have dependencies loaded, we need to re-analyze them and
