@@ -31,6 +31,7 @@ use deno_runtime::deno_web::BlobStore;
 use deno_runtime::permissions::Permissions;
 use log::error;
 use lspower::lsp;
+use once_cell::sync::Lazy;
 use regex::Regex;
 use std::collections::HashMap;
 use std::path::Path;
@@ -61,10 +62,8 @@ const COMPONENT: &percent_encoding::AsciiSet = &percent_encoding::CONTROLS
   .add(b'+')
   .add(b',');
 
-lazy_static::lazy_static! {
-  static ref REPLACEMENT_VARIABLE_RE: Regex =
-    Regex::new(r"\$\{\{?(\w+)\}?\}").unwrap();
-}
+static REPLACEMENT_VARIABLE_RE: Lazy<Regex> =
+  Lazy::new(|| Regex::new(r"\$\{\{?(\w+)\}?\}").unwrap());
 
 fn base_url(url: &Url) -> String {
   url.origin().ascii_serialization()
@@ -483,7 +482,11 @@ impl ModuleRegistry {
   ) -> Result<Vec<RegistryConfiguration>, AnyError> {
     let fetch_result = self
       .file_fetcher
-      .fetch(specifier, &mut Permissions::allow_all())
+      .fetch_with_accept(
+        specifier,
+        &mut Permissions::allow_all(),
+        Some("application/vnd.deno.reg.v2+json, application/vnd.deno.reg.v1+json;q=0.9, application/json;q=0.8"),
+      )
       .await;
     // if there is an error fetching, we will cache an empty file, so that
     // subsequent requests they are just an empty doc which will error without
